ValidationError

Enum ValidationError 

#[non_exhaustive]
pub enum ValidationError { InvalidEdge { src: String, tgt: String, kind: String, reason: String, }, InvalidConstraintSort { vertex: String, sort: String, }, InvalidVertexKind { vertex: String, kind: String, }, DanglingRequiredEdge { vertex: String, edge: String, }, }
An error found during schema validation against a protocol.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidEdge

An edge violates the protocol’s edge rules.

Fields

src: String

The offending edge’s source vertex ID.

tgt: String

The offending edge’s target vertex ID.

kind: String

The edge kind.

reason: String

Human-readable reason for the violation.



InvalidConstraintSort

A constraint uses a sort not recognized by the protocol.

Fields

vertex: String

The vertex with the invalid constraint.

sort: String

The unrecognized sort.



InvalidVertexKind

A vertex kind is not recognized by the protocol.

Fields

vertex: String

The vertex ID.

kind: String

The unrecognized kind.



DanglingRequiredEdge

A required edge references a missing vertex.

Fields

vertex: String

The vertex ID.

edge: String

The dangling edge description.