#[non_exhaustive]pub enum SchemaError {
VertexNotFound(String),
DuplicateVertex(String),
DuplicateEdge {
src: String,
tgt: String,
kind: String,
},
DuplicateHyperEdge(String),
InvalidEdgeSource {
kind: String,
src_kind: String,
permitted: String,
},
InvalidEdgeTarget {
kind: String,
tgt_kind: String,
permitted: String,
},
UnknownEdgeKind(String),
UnknownVertexKind(String),
EmptySchema,
}Expand description
Errors that can occur during schema construction and validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
VertexNotFound(String)
A vertex ID was referenced but not found in the schema.
DuplicateVertex(String)
A duplicate vertex ID was added to the schema.
DuplicateEdge
A duplicate edge was added to the schema.
DuplicateHyperEdge(String)
A duplicate hyper-edge ID was added to the schema.
InvalidEdgeSource
An edge kind violates the protocol’s edge rules.
Fields
InvalidEdgeTarget
An edge kind violates the protocol’s edge rules (target).
Fields
UnknownEdgeKind(String)
An edge kind is not recognized by the protocol.
UnknownVertexKind(String)
A vertex kind is not recognized by the protocol’s schema theory.
EmptySchema
The schema has no vertices.